==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/id/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'Label status tidak ada.',
    'assoc_assets'	 => 'Saat ini label status tersebut terhubung dengan 1 aset dan tidak dapat di hapus. Silahkan perbarui aset anda sehingga tidak terhubung dan kemudian coba kembali. ',


    'create' => array(
        'error'   => 'Label status gagal di buat, silahkan coba lagi.',
        'success' => 'Sukses membuat status label.'
    ),

    'update' => array(
        'error'   => 'Gagal perbarui label status, silahkan coba kembali',
        'success' => 'Sukses perbarui label status.'
    ),

    'delete' => array(
        'confirm'   => 'Anda yakin untuk menghapus model label status ini?',
        'error'   => 'Terdapat kesalahan pada saat penghapusan label status ini. Silahkan coba kembali.',
        'success' => 'Sukses menghapus label status.'
    ),

    'help' => array(
        'undeployable'   => 'Aset ini tidak dapat diberikan kepada siapapun.',
        'deployable'   => 'Aset ini bisa diperiksa. Begitu mereka ditugaskan, mereka akan mengambil status meta <i class="fa fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Aset ini tidak dapat diperiksa, dan hanya akan muncul di tampilan Arsip. Ini berguna untuk menyimpan informasi tentang aset untuk tujuan anggaran / sejarah namun menjauhkan mereka dari daftar aset sehari-hari.',
        'pending'   => 'Aset ini belum bisa diberikan kepada siapapun, sering digunakan untuk barang yang sedang diperbaiki, namun diperkirakan akan kembali beredar.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/id/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'Label status tidak ada.',
    'assoc_assets'	 => 'Saat ini label status tersebut terhubung dengan 1 aset dan tidak dapat di hapus. Silahkan perbarui aset anda sehingga tidak terhubung dan kemudian coba kembali. ',

    'create' => [
        'error'   => 'Label status gagal di buat, silahkan coba lagi.',
        'success' => 'Sukses membuat status label.',
    ],

    'update' => [
        'error'   => 'Gagal perbarui label status, silahkan coba kembali',
        'success' => 'Sukses perbarui label status.',
    ],

    'delete' => [
        'confirm'   => 'Anda yakin untuk menghapus model label status ini?',
        'error'   => 'Terdapat kesalahan pada saat penghapusan label status ini. Silahkan coba kembali.',
        'success' => 'Sukses menghapus label status.',
    ],

    'help' => [
        'undeployable'   => 'Aset ini tidak dapat diberikan kepada siapapun.',
        'deployable'   => 'These assets can be checked out. Once they are assigned, they will assume a meta status of <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Aset ini tidak dapat diperiksa, dan hanya akan muncul di tampilan Arsip. Ini berguna untuk menyimpan informasi tentang aset untuk tujuan anggaran / sejarah namun menjauhkan mereka dari daftar aset sehari-hari.',
        'pending'   => 'Aset ini belum bisa diberikan kepada siapapun, sering digunakan untuk barang yang sedang diperbaiki, namun diperkirakan akan kembali beredar.',
    ],

];
